Package 'rob'

Title: What the Package Does (One Line, Title Case)
Description: What the package does (one paragraph).
Authors: Romario Conto [aut, cre] (ORCID: YOUR-ORCID-ID)
Maintainer: Romario Conto <[email protected]>
License: MIT + file LICENSE
Version: 0.0.0.9000
Built: 2026-05-17 05:34:33 UTC
Source: https://github.com/romariocontol/rob

Help Index


Function to add a new column to the matrix

Description

Function to add a new column to the matrix

Usage

adcol(x, y, z, run)

Arguments

x

levels vector of the new factor

y

number of levels of the new factor

z

level vector of the initial matrix

run

initial run matrix

Value

matrix with the new run order

Examples

x = matrix(c(-1, 1), ncol = 1)
y = length(x)
z = c(2,2,2)
run=matrix(c(1,-1,1,-1,1,1,-1,-1), ncol=2)
adcol(x,y,z,run)

Assignment-Expansion method

Description

Assignment-Expansion method

Usage

runorder(z)

Arguments

z

vector with the levels of the factor

Value

order of experimentation with bias and number of level changes in balance

Examples

z<-c(2,2,2,2,2,2)
runorder(z)
z<-c(4,3,2,3,2)
runorder(z)
z<-c(3,3,2,4)
runorder(z)